@@ -1,14 +1,11 @@
 package Dist::Zilla::PluginBundle::SCHWIGON;
-# git description: v0.011-1-g7b282a9
+# git description: v0.012-5-g2657fb2
 
 BEGIN {
   $Dist::Zilla::PluginBundle::SCHWIGON::AUTHORITY = 'cpan:SCHWIGON';
 }
-{
-  $Dist::Zilla::PluginBundle::SCHWIGON::VERSION = '0.012';
-}
 # ABSTRACT: Build your distributions like SCHWIGON does
-
+$Dist::Zilla::PluginBundle::SCHWIGON::VERSION = '0.013';
 # (well actually like FLORA - as it is shamelessly stolen)
 
 use Moose 1.00;
@@ -135,6 +132,16 @@ has homepage_url => (
     },
 );
 
+has skip_pod_modules => (
+    is      => 'ro',
+    isa     => Str,
+    lazy    => 1,
+    default => '',
+    handles => {
+        skip => 'as_string',
+    },
+);
+
 method _build_homepage_url {
     return sprintf $self->_cpansearch_pattern, $self->dist;
 }
@@ -316,10 +323,13 @@ method configure {
         PodSyntaxTests
     ));
 
-    $self->add_plugins('NoTabsTests')
+    $self->add_plugins('Test::NoTabs')
         unless $self->disable_tab_tests;
 
-    $self->add_plugins('PodCoverageTests')
+    $self->add_plugins(
+        ['Test::Pod::Coverage::Configurable' => {
+            'skip'          => $self->skip_pod_modules,
+         }])
         unless $self->disable_pod_coverage_tests;
 
     $self->add_plugins(
@@ -335,7 +345,7 @@ method configure {
             authority   => $self->authority,
             do_metadata => 1,
         }],
-        [EOLTests => {
+        ['Test::EOL' => {
             trailing_whitespace => $self->disable_trailing_whitespace_tests ? 0 : 1,
         }],
     );
@@ -396,8 +406,6 @@ In dist.ini:
   [@SCHWIGON]
   dist = Distribution-Name
   repository_at = github
-  ; static_version = 7.89
-  ; release_branch = public-releases
 
 =head1 DESCRIPTION
 
@@ -413,8 +421,8 @@ It is roughly equivalent to:
   [PkgVersion]
   [PodSyntaxTests]
   [PodCoverageTests]
-  [NoTabsTests]
-  [EOLTests]
+  [Test::NoTabs]
+  [Test::EOL]
 
   [MetaResources]
   repository.type   = git
@@ -434,10 +442,10 @@ It is roughly equivalent to:
   [AutoPrereqs]
   [Git::Describe]
 
-  [NextRelease]
-
   [CheckChangesHasContent]
 
+  [NextRelease]
+
   [Git::CheckFor::CorrectBranch]
   release_branch = master
 
@@ -454,7 +462,7 @@ Steffen Schwigon <ss5@renormalist.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Steffen Schwigon.
+This software is copyright (c) 2015 by Steffen Schwigon.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
